@@ -2,20 +2,24 @@
 #
 # demo.pl - Redland CGI database and query demo Perl program
 #
-# $Id: demo.pl,v 1.7 2003/08/28 15:31:20 cmdjb Exp $
+# $Id: demo.pl 10586 2006-03-05 07:49:32Z cmdjb $
 #
-# Copyright (C) 2000-2003 David Beckett - http://purl.org/net/dajobe/
-# Institute for Learning and Research Technology - http://www.ilrt.org/
-# University of Bristol - http://www.bristol.ac.uk/
+# Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+# Copyright (C) 2000-2004, University of Bristol, UK http://www.bristol.ac.uk/
 # 
-# This package is Free Software or Open Source available under the
-# following licenses (these are alternatives):
-#   1. GNU Lesser General Public License (LGPL)
-#   2. GNU General Public License (GPL)
-#   3. Mozilla Public License (MPL)
+# This package is Free Software and part of Redland http://librdf.org/
+# 
+# It is licensed under the following three licenses as alternatives:
+#   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
+#   2. GNU General Public License (GPL) V2 or any newer version
+#   3. Apache License, V2.0 or any newer version
+# 
+# You may not use this file except in compliance with at least one of
+# the above three licenses.
 # 
 # See LICENSE.html or LICENSE.txt at the top of this package for the
-# full license terms.
+# complete terms and further detail along with the license texts for
+# the licenses in COPYING.LIB, COPYING and LICENSE-2.0.txt respectively.
 # 
 # 
 #
@@ -40,13 +44,18 @@ use URI::URL;
 
 my(@commands)=qw(destroy query parse add print),
 my(%command_labels)=('destroy'  =>'Delete database',
-		     'query'    =>'Find statements',
-		     'add',     =>'Add a statement',
+		     'query'    =>'Find triples',
+		     'add',     =>'Add a triple',
 		     'parse',   =>'Parse RDF',
 		     'print',   =>'Print database');
+my(%command_needs_write)=('destroy'  =>1,
+			  'query'    =>0,
+			  'add',     =>1,
+			  'parse',   =>1,
+			  'print',   =>0);
 my(@parsers)=qw(raptor ntriples);
-my(%parser_labels)=('raptor' => 'Raptor RDF/XML (Dave Beckett)',
-		    'ntriples' => 'Raptor N-Triples (Dave Beckett)'
+my(%parser_labels)=('raptor' => 'RDF/XML',
+		    'ntriples' => 'N-Triples'
 		    );
 my(%parser_just_file_uris)=('raptor' => 1,
 			    'ntriples' => 1
@@ -74,6 +83,8 @@ my(%namespaces)=(
   'rss' => 'http://purl.org/rss/1.0/',
   'synd' => 'http://purl.org/rss/1.0/modules/syndication/',
   'dc' => 'http://purl.org/dc/elements/1.1/',
+  'owl' => 'http://www.w3.org/2002/07/owl#',
+  'xsd' => 'http://www.w3.org/2001/XMLSchema#',
 );
 
 
@@ -101,7 +112,7 @@ sub end_page($) {
   print <<'EOT';
 <p>The source code of this demonstration is available in the Redland
 distribution as <tt>demos/demo.pl</tt> or from the
-<a href="http://www.redland.opensource.ac.uk/">Redland</a> website</p>
+<a href="http://librdf.org/">Redland</a> website</p>
 EOT
 
   print qq{<hr />\n\n<p class="copyright"><a href="http://purl.org/net/dajobe/">Dave Beckett</a></p>\n\n</body>\n</html>\n};
@@ -132,7 +143,7 @@ if(defined $val && $val =~ /^([a-z]+)$/) {
 }
 
 my $statement_string;
-$val=$q->param('statement');
+$val=($q->param('triple') || $q->param('statement'));
 if(defined $val && $val =~ /^([ -~]+)$/) {
   $statement_string=$1;
 } else {
@@ -155,11 +166,14 @@ if(defined $val && $val =~ /^([a-z]+)$/) {
   $parser_string=undef;
 }
 
-my $rdf_content='';
+my $rdf_content=undef;
 $val=$q->param('content');
 # WARNING: pass through of all data
-if(defined $val && $val =~ /^(.*)$/s) {
-  $rdf_content=$1;
+if(defined $val) {
+  $val=~ s/^\s*//; $val=~ s/\s*$//;
+  if($val =~ /^(.+)$/s) {
+    $rdf_content=$1;
+  }
 }
 
 my $format_namespaces='';
@@ -199,31 +213,31 @@ print <<"EOT";
 
 <ol>
 <li>Pick a database name</li>
-<li><p>Add some RDF statements to the database in one of these ways:</p>
+<li><p>Add some RDF triples to the database in one of these ways:</p>
 <ol>
-  <li>Enter a statement by hand in the <em>Statement</em> field and
-  use the <em>Add a statement</em> command.</li>
+  <li>Enter a triple by hand in the <em>Triple</em> field and
+  use the <em>Add a triple</em> command.</li>
   <li>Enter some RDF/XML or N-Triples in the <em>Content</em> area and
   use the <em>Parse RDF</em> command.</li>
   <li>Give the URI of the RDF/XML or N-Triples on the web to parse in the <em>URI</em> field and
   use the <em>Parse RDF</em> command.</li>
 </ol>
 <li>Print the database - select the <em>Print database</em> command.</li>
-<li>Query the database - either click on the statements from the result of the
-previous command</li> <strong>or</strong> enter a statement in the <em>statement</em> field and use the <em>Find statements</em> command to return matching statements</li>
+<li>Query the database - either click on the triples from the result of the
+previous command</li> <strong>or</strong> enter a triple in the <em>triple</em> field and use the <em>Find triples</em> command to return matching triples</li>
 <li>Delete the database when you are done - thanks!</li>
 </ol>
 
 
-<p>The syntax of statements is as follows. A statement about a resource is written as:</p>
+<p>The syntax of triples is as follows. A triple about a resource is written as:</p>
 <pre>  [subject]--[predicate]-->[object]</pre>
 
-<p>and a statement with a string value is written as:</p>
+<p>and a triple with a string value is written as:</p>
 <pre>  [subject]--[predicate]-->"object"</pre>
 
 <p>When used as a query, replace any of the parts with <tt>?</tt>
 to match anything e.g.: <tt>?--?-->"foo"</tt> to
-return all statements which have the object string <em>foo</em>.</p>
+return all triples which have the object string <em>foo</em>.</p>
 
 <!-- DB PRIVACY BLURB HERE -->
 
@@ -249,12 +263,12 @@ print $q->popup_menu(-name=>'command',
 		     -default=>$default_command, 
 		     -labels=>\%command_labels);
 
-print "\n\n<p><em>Statement</em> (for <em>Find</em> and <em>Add Statements</em> commands):\n";
-print $q->textfield(-name=>'statement',
+print "\n\n<p><em>Triple</em> (for <em>Find</em> and <em>Add Triples</em> commands):\n";
+print $q->textfield(-name=>'triple',
 		    -default=>'',
 		    -size=>80);
 
-print "\n\n<p>RDF Parser for <em>Parse RDF</em> command\n";
+print "\n\n<p>RDF content syntax the <em>Parse RDF</em> command\n";
 print $q->popup_menu(-name=>'parser', 
 		     -values=>\@parsers,
 		     -default=>$parsers[0], 
@@ -319,12 +333,14 @@ if($parser_string && !grep($_ eq $parser_string, @parsers)) {
 }
 
 
+my $model=undef;
+my $storage=undef;
 
 my $db0="$db_dir/".sprintf($db_format, $db, $suffixes[0]);
 if(! -r $db0) {
-  my $storage=new RDF::Redland::Storage("hashes", $db, 
-			       "new='yes',write='yes',hash-type='bdb',dir='$db_dir'");
-  my $model;
+  my $write=$command_needs_write{$command} ? 'yes' : 'no';
+  $storage=new RDF::Redland::Storage("hashes", $db, 
+			       "new='yes',write='$write',hash-type='bdb',dir='$db_dir'");
   if($storage) {
     $model=new RDF::Redland::Model($storage, "");
   }
@@ -349,37 +365,42 @@ if($command eq 'destroy') {
 }
 
 
-# Remaining commands need an open database
-# Write needed?
-my $write=($command eq 'parse' || $command eq 'add') ? 'yes' : 'no';
-my $storage=new RDF::Redland::Storage("hashes", $db, 
-			     "new='no',write='$write',hash-type='bdb',dir='$db_dir'");
-if(!$storage) {
-  log_action($host, $db, "Failed to open storage");
-  print "\n\n<p>Sorry - failed to open RDF Database $db.  This problem has been recorded.</p>\n";
-  end_page($q);
-  exit 0;
+# If model wasn't created/opened above, create and open now
+if(!$model) {
+  # Remaining commands need an open database
+  my $write=$command_needs_write{$command} ? 'yes' : 'no';
+  # Unless exists already and not writable
+  $write='no' if -r $db0 && !-w $db0;
+  $storage=new RDF::Redland::Storage("hashes", $db, 
+				     "new='no',write='$write',hash-type='bdb',dir='$db_dir'");
+  if(!$storage) {
+    log_action($host, $db, "Failed to open storage");
+    print "\n\n<p>Sorry - failed to open RDF Database $db.  This problem has been recorded.</p>\n";
+    end_page($q);
+    exit 0;
+  }
+  
+  $model=new RDF::Redland::Model($storage, "");
+  if(!$model) {
+    log_action($host, $db, "Failed to create model");
+    print "\n\n<p>Sorry - failed to open RDF Model for RDF Database $db.  This problem has been recorded.</p>\n";
+    end_page($q);
+    exit 0;
+  }
 }
 
-my $model=new RDF::Redland::Model($storage, "");
-if(!$model) {
-  log_action($host, $db, "Failed to create model");
-  print "\n\n<p>Sorry - failed to open RDF Model for RDF Database $db.  This problem has been recorded.</p>\n";
-  end_page($q);
-  exit 0;
-}
 
 my $statement=undef;
 my $stream=undef;
 
-if($command ne 'print'  && $command ne 'parse') {
+if($command ne 'print' && $command ne 'parse') {
   if ($statement_string !~ m%^ (?: \? | \[[^]]+\])
                                \s*--\s*
                                (?: \? | \[[^]]+\])
                                \s*--\>\s*
                                (?: \? | [\["] [^]"]+ [\]"]) $%x) { # "
     print <<"EOT";
-\n\n<p>Sorry, I do not understand the statement syntax; it should match that
+\n\n<p>Sorry, I do not understand the triple syntax; it should match that
 described above.</p>
 EOT
     end_page($q);
@@ -466,7 +487,7 @@ if($command eq 'print') {
     }
   }
 
-  if($rdf_content) { # have content on web page, maybe with URI
+  if(defined $rdf_content) { # have content on web page, maybe with URI
     $temp_file="$tmp_dir/redland-demo-$$.rdf";
     if(open(OUT, ">$temp_file")) {
       print OUT $rdf_content;
@@ -578,24 +599,25 @@ for(;!$stream->end ;  $stream->next) {
 
   $q->delete('content');  # HACK - makes generated URIs just too large
 
-  $q->param('statement', "$subject--?-->?");
+  $q->param('triple', "$subject--?-->?");
   my $subject_query=$q->self_url;
 
-  $q->param('statement', "?--$predicate-->?");
+  $q->param('triple', "?--$predicate-->?");
   my $predicate_query=$q->self_url;
 
   if($object =~ /^\[(.+)\]$/) {
-    $q->param('statement', "?--?-->[$1]");
+    $q->param('triple', "?--?-->[$1]");
   } else {
     $object=qq{"$object"};
-    $q->param('statement', "?--?-->$object");
+    $q->param('triple', "?--?-->$object");
   }
 
-  my $object_query=$q->self_url;
-
+  my $object_string=$object_label;
   my $from_object='';
   if($object =~ /^\[(.+)\]$/) {
-    $q->param('statement', "[$1]--?-->?");
+    my $object_query=$q->self_url;
+    $q->param('triple', "[$1]--?-->?");
+    $object_string=qq{<a href="$object_query">$object_label</a>};
     $from_object=qq{<a href="}.$q->self_url.qq{">Follow</a>};
   } else {
     $from_object='&nbsp;';
@@ -605,7 +627,7 @@ for(;!$stream->end ;  $stream->next) {
 <tr>
 <td><a href="$subject_query">$subject_label</a></td>
 <td><a href="$predicate_query">$predicate_label</a></td>
-<td><a href="$object_query">$object_label</a></td>
+<td>$object_string</td>
 <td>$from_object</td>
 </tr>
 EOT
@@ -639,14 +661,15 @@ print <<"EOT";
 EOT
 
 my $pl=($count != 1) ? 's' : '';
-print "\n\n<p>Found $count statement$pl</p>\n";
+print "\n\n<p>Found $count triple$pl</p>\n";
 
 if($format_namespaces) {
- print "<p>Where the following namespace prefixes were used:";
- while(my($ns_prefix,$ns_uri)=each %namespaces) {
-   print qq{<br />\n${ns_prefix}: is namespace <a href="${ns_uri}">${ns_uri}</a>};
+ print "<p>Where the following namespace prefixes were used:</p>\n<dl>";
+ for my $ns_prefix (sort keys %namespaces) {
+   my $ns_uri=$namespaces{$ns_prefix};
+   print qq{<dt>${ns_prefix}<br /></dt>\n<dd>namespace <a href="${ns_uri}">${ns_uri}</a></dd>\n};
  }
- print "\n</p>\n\n";
+ print "\n</dl>\n\n";
 }
 
 end_page($q);
